
// vim: set filetype=pp2html:

=BR or LINE_BREAK

\X{mode=index_only}<Tag \\BR>
\X{mode=index_only}<Tag \\LINE_BREAK>
The \B<\\BR> tag and (as a synonym \B<\\LINE_BREAK>) can be used to force a line break in the
text output. This is converted to the HTML <BR> tag.


\B<Syntax>

\\BR

\\LINE_BREAK


\B<Options>

No options are allowed. Using options will cause a syntax error.


\B<Body>

No body is allowed.



\B<Example>

  This text is wrapped\\BR
  just before just ...

produces

This text is wrapped\BR
just before just ...


\B<See also>

\B<\\HR>

