

// vim: set filetype=pp2html:

=U

\X{mode=index_only}<Tag \\U>
The \B<\\U> tag marks text to be formatted as \I<\B<u>nderligned>.


\B<Syntax>

\\U<body>


\B<Options>

No options are allowed. Using options will cause a syntax error.


\B<Body>

The body is the string to be formatted.


\B<Example>

  This is very \\U<important>.


produces

  This is very \U<important>.


\B<See also>

\B<\\SUB>, \B<\\SUP>, \B<\\F>

