
// vim: set filetype=PerlPoint:


=Numbered or Not Numbered Headlines

\QST

How can I get \X<numbered headlines> and how can I suppress the numbering?

\ANS

This can be achieved by the \C<--num_headers> option and the \C<--nonum_headers> option
respectively.

\DSC

The \C<--nonum_headers> option may be used to overwrite the \C<--num_headers> option from a
predefined style. 

