<!-- ---- Top Navigation Bar ------------------------------------- BEGIN 
  $Id: big_blue-top.tpl,v 1.2 2001/12/06 21:38:12 lorenz Exp $
-------------------------------------------------------------------- -->
<!--
  *** This text is included just below the BODY line in all HTML pages
  $Id: big_blue-top.tpl,v 1.2 2001/12/06 21:38:12 lorenz Exp $
  $Revision: 1.2 $
  $Date: 2001/12/06 21:38:12 $
-->
<FONT SIZE=+6>

<TABLE bgcolor="#FFFF99" WIDTH=100%  BORDER=0 CELLSPACING=0>
<TR>
  <TD bgcolor="#FFFF99" valign=center WIDTH=20% >
     <a href="http://www.perlworkshop.de"><img src="karawane-50.gif" border=0></a>
  </TD>
  <TD align=center bgcolor="#FFFF99">
     <FONT SIZE=+2 color=black><B>
       TITLE
     </B></FONT>
  </TD>
  <TD align=right WIDTH=20% bgcolor="#FFFF99">
     PAGE
  </TD>
</TR>
</TABLE>
<HR>

<TABLE> 
<TR>
  <TD colspan=3 >
    LABEL_NEXT:  <a href="URL_NEXT">TXT_NEXT</a>
    &nbsp;&nbsp;LABEL_PREV:  <a href="URL_PREV">TXT_PREV</a>
     &nbsp;&nbsp;LABEL_CONTENTS: <a href="URL_CONTENTS">TXT_CONTENTS</a>
  </td>
</TR>
</TABLE>
<P>
<!-- ---- Top Navigation Bar ---------------------------------- END -->
