=Test of Sectioning

This document has the following sequence of headers:

 \\section
 \\subsection
 \\subsubsection
 \\Paragraph
 \\textit
 \\textit
 ....

==Level 2 Header

This should be a \C<\\subsection>

===Level 3 Header

This should be a \C<\\subsubsection>

====Level 4 Header

This should be a \C<\\paragraph>

=====Level 5 Header

This should be a \C<\\textit>

======Level 6 Header

This should be a \C<\\textit>


=OK return to Level One

This is a \C<\\section>

