
// vim: set filetype=pp2html:

=SUP

\X{mode=index_only}<Tag \\SUP>
The \B<\\SUP> tag marks text to be formatted as \I<\B<sup>erscript>.


\B<Syntax>

\\SUP<body>


\B<Options>

No options are allowed. Using options will cause a syntax error.


\B<Body>

The body is the string to be formatted.


\B<Example>

  E = m c\\SUP<2>


produces

  E = m c\SUP<2>


\B<See also>

\B<\\SUB>, \B<\\U>, \B<\\F>

