
// vim: set filetype=pp2html:

HR=

\X{mode=index_only}<Tag \\HR>
The \B<\\HR> tag creates a horizontal line. This is translated to the HTML <HR> tag.


\B<Syntax>

\\HR


\B<Options>

No options are allowed. Using options will cause a syntax error.


\B<Body>

No body is allowed

\B<See also>

\B<\\BR> \B<\\LINE_BREAK>

