
// vim: set filetype=pp2html:

=SUB

\X{mode=index_only}<Tag \\SUB>
The \B<\\SUB> tag marks text to be formatted as \I<\B<sub>script>.


\B<Syntax>

\\SUB<body>


\B<Options>

No options are allowed. Using options will cause a syntax error.


\B<Body>

The body is the string to be formatted.


\B<Example>

  S = sum(A\\SUB<i>)  (i = 1, ..., 8)

produces

  S = sum(A\SUB<i>)  (i = 1, ..., 8)



\B<See also>

\B<\\SUP>, \B<\\U>, \B<\\F>

